<?php
// This file serves as an example of how to realize a custom theme.
// The "Hello World" theme is the simplest one we could produce

// The color skins in Zorum are theoretically completely independent
// from the themes. However, it happens often that a theme defines its
// own colors and colorful images, and it won't look good if e.g. the
// page background color depends on the current skin. Therefore, it is
// possible to "fix" the colors of the skins! If you specify here the 
// colors you want to "attach" to your custom theme, it won't change
// any more in case of the color skin changes. E.g. if you know that the
// white is the only page background that fits to your theme, and set 
// here $zorumSkin->bg to 'white', the background will remain always
// white  when somebody applies your theme. 

// The skin colors you can
// reasonably overwrite here are the following:

//$zorumSkin->bg="white"; // page background
//$zorumSkin->textcol="#000033";  // default color of the texts
//$zorumSkin->linkcol="#000066"; // default color of the links
//$zorumSkin->line="#8c0000"; // the color of the lines of the tables
//$zorumSkin->thboxheaderbg="#8c0000"; // the bg color of the header of a 
                                     // portal box
//$zorumSkin->thboxcellbg="#000000"; // the bg color of the of a 
                                   // portal box
//$zorumSkin->thboxactcellbg="#222222"; // the bg color of an active
                                      // menupoint in a box
//$zorumSkin->thboxfooterbg="#8c0000"; // the bg color of the header of a 
                                     // portal box

// However, you can easily create a theme that doesn't have fix colors!
// In this case, you can use the above colors in the showPortalBox
// function below, instead of overwriting them. This way, the current 
// color of your theme will depend on the applied color skin in Zorum.
// This concept allows higher flexibility an personalization 
// capability.

// This is the path of your theme (you don't have to care about what
// $dotDot means), you can write here an absolute path instead of this
// relative, too, if you want:

$iP="$dotDot/themes/hello_world";

// You can define this way the image background of the whole page, if 
// your custom theme requires. This will overlap the bg color of 
// $zorumSkin->bg

//$bodyBgImg="$iP/temple.jpg";

// The portal page is divided into three columns: the left side with
// boxes, the middle part with the content, and the left side again 
// with boxes (the right and the left columns are optional, e.g. there
// is no right column if none of the boxes is ordered to the right with
// the box organizer

// You can overwrite the default appearance of these three columns: 
// theit width and their background color, or image:

//$portalLeftWidth="";
//$portalLeftBgImg="";
//$portalLeftBgCol="";
//$portalMiddleWidth="";
//$portalMiddleBgImg="";
//$portalMiddleBgCol="";    
//$portalRightWidth="";
//$portalRightBgImg="";
//$portalRightBgCol="";

// The purpose of this function is to "frame" the fix content of a 
// portal box with a custom design.
// The parameters:
// $s: the output of the function - an HTML-code that displays a box.
// $headerText: the header of the box, it can also be empty
// $innerText: the inner content of the box, it can also be an array
//             in case of a menu box
// $footerText: the footer of the box, it can be empty
// $active: if $innerText is an array (represents a menu list), $active
//          shows which menu item is the active one. -1 means none of
//          them is active, 0 means the first item is active, etc.

function showPortalBox( &$s, $headerText, $innerText, $footerText="", 
                        $active=-1 )
{
    global $iP;
    global $zorumSkin;
    
    $s="";
    $s.="<table cellspacing=0 cellpadding=0 width=100% border=1>\n";
    if ($headerText!="") 
    {
        $s.="<tr>";
        $s.="<th align='center' bgcolor='$zorumSkin->thboxheaderbg'>";
        
        $s.=$headerText;
        
        $s.="</th>\n";
        $s.="</tr>\n";
    }    
    $s.="<tr><td bgcolor='$zorumSkin->thboxcellbg'>\n";
    
    if( is_array($innerText) ) 
    {
        foreach($innerText as $item) $s.="$item<br>\n";
    }    
    else $s.="$innerText";
    
    $s.="</td></tr>";
    if ($footerText!="") 
    {
        $s.="<tr>";
        $s.="<th align='center' bgcolor='$zorumSkin->thboxfooterbg'>";
        
        $s.=$footerText;
        
        $s.="</th>\n";
        $s.="</tr>\n";
    }    
    
    $s.="</table>\n";
    return ok;
}
?>
